@@ -1,10 +1,12 @@
 use super::*;
+use crate::styles::{Gradient, Image};
+use std::ops::AddAssign;
 
 /// Get default style when not specified.
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct BackgroundStyle {
     /// Get the config of [`crate::BackgroundColor`]
-    pub background_color: RGBA,
+    pub background_texture: Texture,
 }
 
 /// Get default style when not specified.
@@ -14,39 +16,39 @@ pub struct CircleStyle {
     pub circle_width: f32,
 
     /// Get the config of [`crate::CircleColor`]
-    pub circle_color: RGBA,
+    pub circle_texture: Texture,
 }
 
 /// Get default style when not specified.
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct DiskStyle {
     /// Get the config of [`crate::DiskFillColor`]
-    pub disk_fill_color: RGBA,
+    pub disk_fill_color: Color,
 
     /// Get the config of [`crate::DiskEdgeWidth`]
     pub disk_edge_width: f32,
 
     /// Get the config of [`crate::DiskEdgeColor`]
-    pub disk_edge_color: RGBA,
+    pub disk_edge_color: Color,
 }
 
 /// Get default style when not specified.
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct EdgeColor {
     /// Get the config of [`crate::DiskEdgeColor`]
-    pub disk_edge_color: RGBA,
+    pub disk_edge_color: Color,
 
     /// Get the config of [`crate::TriangleEdgeColor`]
-    pub triangle_edge_color: RGBA,
+    pub triangle_edge_color: Color,
 
     /// Get the config of [`crate::SquareEdgeColor`]
-    pub square_edge_color: RGBA,
+    pub square_edge_color: Color,
 
     /// Get the config of [`crate::RectangleEdgeColor`]
-    pub rectangle_edge_color: RGBA,
+    pub rectangle_edge_color: Color,
 
     /// Get the config of [`crate::PolygonEdgeColor`]
-    pub polygon_edge_color: RGBA,
+    pub polygon_edge_color: Color,
 }
 
 /// Get default style when not specified.
@@ -56,7 +58,7 @@ pub struct EdgeStyle {
     pub disk_edge_width: f32,
 
     /// Get the config of [`crate::TriangleEdgeColor`]
-    pub triangle_edge_color: RGBA,
+    pub triangle_edge_color: Color,
 }
 
 /// Get default style when not specified.
@@ -82,19 +84,19 @@ pub struct EdgeWidth {
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct FillColor {
     /// Get the config of [`crate::DiskFillColor`]
-    pub disk_fill_color: RGBA,
+    pub disk_fill_color: Color,
 
     /// Get the config of [`crate::TriangleFillColor`]
-    pub triangle_fill_color: RGBA,
+    pub triangle_fill_color: Color,
 
     /// Get the config of [`crate::SquareFillColor`]
-    pub square_fill_color: RGBA,
+    pub square_fill_color: Color,
 
     /// Get the config of [`crate::RectangleFillColor`]
-    pub rectangle_fill_color: RGBA,
+    pub rectangle_fill_color: Color,
 
     /// Get the config of [`crate::PolygonFillColor`]
-    pub polygon_fill_color: RGBA,
+    pub polygon_fill_color: Color,
 }
 
 /// Get default style when not specified.
@@ -104,7 +106,7 @@ pub struct LineStyle {
     pub line_width: f32,
 
     /// Get the config of [`crate::LineColor`]
-    pub line_color: RGBA,
+    pub line_color: Color,
 }
 
 /// Get default style when not specified.
@@ -114,20 +116,20 @@ pub struct PointStyle {
     pub point_size: f32,
 
     /// Get the config of [`crate::PointColor`]
-    pub point_color: RGBA,
+    pub point_color: Color,
 }
 
 /// Get default style when not specified.
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct PolygonStyle {
     /// Get the config of [`crate::PolygonFillColor`]
-    pub polygon_fill_color: RGBA,
+    pub polygon_fill_color: Color,
 
     /// Get the config of [`crate::PolygonEdgeWidth`]
     pub polygon_edge_width: f32,
 
     /// Get the config of [`crate::PolygonEdgeColor`]
-    pub polygon_edge_color: RGBA,
+    pub polygon_edge_color: Color,
 }
 
 /// Get default style when not specified.
@@ -137,40 +139,40 @@ pub struct PolylineStyle {
     pub polyline_width: f32,
 
     /// Get the config of [`crate::PolylineColor`]
-    pub polyline_color: RGBA,
+    pub polyline_color: Color,
 }
 
 /// Get default style when not specified.
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct RectangleStyle {
     /// Get the config of [`crate::RectangleFillColor`]
-    pub rectangle_fill_color: RGBA,
+    pub fill_texture: Color,
 
     /// Get the config of [`crate::RectangleEdgeWidth`]
-    pub rectangle_edge_width: f32,
+    pub edge_width: f32,
 
     /// Get the config of [`crate::RectangleEdgeColor`]
-    pub rectangle_edge_color: RGBA,
+    pub rectangle_edge_color: Color,
 }
 
 /// Get default style when not specified.
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct SquareStyle {
     /// Get the config of [`crate::SquareFillColor`]
-    pub square_fill_color: RGBA,
+    pub square_fill_color: Color,
 
     /// Get the config of [`crate::SquareEdgeWidth`]
     pub square_edge_width: f32,
 
     /// Get the config of [`crate::SquareEdgeColor`]
-    pub square_edge_color: RGBA,
+    pub square_edge_color: Color,
 }
 
 /// Get default style when not specified.
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct TextStyle {
     /// Get the config of [`crate::TextColor`]
-    pub text_color: RGBA,
+    pub text_color: Color,
 
     /// Get the config of [`crate::TextSize`]
     pub text_size: f32,
@@ -183,26 +185,26 @@ pub struct TextStyle {
 #[derive(Clone, Copy, Debug, PartialEq, Serialize, Deserialize)]
 pub struct TriangleStyle {
     /// Get the config of [`crate::TriangleFillColor`]
-    pub triangle_fill_color: RGBA,
+    pub triangle_fill_color: Color,
 
     /// Get the config of [`crate::TriangleEdgeWidth`]
     pub triangle_edge_width: f32,
 
     /// Get the config of [`crate::TriangleEdgeColor`]
-    pub triangle_edge_color: RGBA,
+    pub triangle_edge_color: Color,
 }
 
-impl StyleResolver {
+impl StyleContext {
     /// Get the [`crate::BackgroundStyle`] from theme and state.
     pub fn resolve_background_style(&self, style: crate::BackgroundStyle) -> BackgroundStyle {
-        BackgroundStyle { background_color: style.background_color.unwrap_or(self.background_color()).value }
+        BackgroundStyle { background_texture: style.background_color.unwrap_or(self.background_color()).value }
     }
 
     /// Get the [`crate::CircleStyle`] from theme and state.
     pub fn resolve_circle_style(&self, style: crate::CircleStyle) -> CircleStyle {
         CircleStyle {
             circle_width: style.circle_width.unwrap_or(self.circle_width()).value,
-            circle_color: style.circle_color.unwrap_or(self.circle_color()).value,
+            circle_color: style.circle_texture.unwrap_or(self.circle_color()).value,
         }
     }
 
@@ -292,8 +294,8 @@ impl StyleResolver {
     /// Get the [`crate::RectangleStyle`] from theme and state.
     pub fn resolve_rectangle_style(&self, style: crate::RectangleStyle) -> RectangleStyle {
         RectangleStyle {
-            rectangle_fill_color: style.rectangle_fill_color.unwrap_or(self.rectangle_fill_color()).value,
-            rectangle_edge_width: style.rectangle_edge_width.unwrap_or(self.rectangle_edge_width()).value,
+            fill_texture: style.rectangle_fill_color.unwrap_or(self.rectangle_fill_color()).value,
+            edge_width: style.rectangle_edge_width.unwrap_or(self.rectangle_edge_width()).value,
             rectangle_edge_color: style.rectangle_edge_color.unwrap_or(self.rectangle_edge_color()).value,
         }
     }
