@@ -1,11 +1,16 @@
-mod add_assign;
+use crate::*;
 mod convert;
-mod draw_style;
-use crate::{resolver::StyleContext, *};
-use std::{cmp::Ordering, ops::AddAssign};
+#[cfg(feature = "wolfram-expr")]
+mod wolfram;
+use std::fmt::{Debug, Formatter};
 
 /// Trait for drawing a shape with a style.
+#[allow(unused_variables)]
 pub trait GraphicsStyle {
+    /// Draws a shape with a style.
+    fn skip(&self) -> bool {
+        false
+    }
     /// Draws a shape with a style.
     ///
     /// # Arguments
@@ -17,26 +22,24 @@ pub trait GraphicsStyle {
     /// # Examples
     ///
     /// ```rust
-    /// use graphics_style::{GraphicsStyle, StyleContext, RGBA};
+    /// use graphics_style::{Color, GraphicsStyle3D, StyleContext};
     /// pub struct CustomLineStyle {
     ///     pub width: f32,
-    ///     pub color: RGBA,
+    ///     pub color: Color,
     /// }
     ///
-    /// impl GraphicsStyle for CustomLineStyle {
-    ///     fn draw_style(&self, state: &mut StyleContext) {
+    /// impl GraphicsStyle3D for CustomLineStyle {
+    ///     fn change_style(&self, state: &mut StyleContext) {
     ///         state.line_width = Some(self.width);
     ///         state.line_color = Some(self.color);
     ///     }
     /// }
     /// ```
-    fn draw_style(&self, state: &mut StyleContext);
-    /// Draws a shape with a style.
-    fn skip(&self) -> bool {
-        false
-    }
+    fn change_style(&self, state: &mut StyleContext);
 }
 
-impl GraphicsStyle for () {
-    fn draw_style(&self, _: &mut StyleContext) {}
+impl Debug for dyn GraphicsStyle {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "GraphicsStyle")
+    }
 }
